@@ -4,6 +4,7 @@
 //! Configuration elements for nextest.
 
 mod archive;
+pub(super) mod bench;
 mod global_timeout;
 mod inherits;
 mod junit;
@@ -11,12 +12,13 @@ mod leak_timeout;
 mod max_fail;
 mod priority;
 mod retry_policy;
-mod slow_timeout;
+pub(super) mod slow_timeout;
 mod test_group;
 mod test_threads;
 mod threads_required;
 
 pub use archive::*;
+pub(super) use bench::*;
 pub use global_timeout::*;
 pub use inherits::*;
 pub use junit::*;
