@@ -26,6 +26,7 @@ use crate::{
         JobControlEvent, ShutdownEvent, ShutdownSignalEvent, SignalEvent, SignalHandler,
         SignalInfoEvent,
     },
+    test_output::ChildSingleOutput,
     time::StopwatchStart,
 };
 use chrono::Local;
@@ -363,7 +364,7 @@ where
     pub(super) fn run_started(&mut self, test_list: &'a TestList, test_threads: usize) {
         let (stress_count, stress_infinite, stress_duration_nanos) =
             match self.stress_cx.condition() {
-                Some(StressCondition::Count(StressCount::Count(count))) => {
+                Some(StressCondition::Count(StressCount::Count { count })) => {
                     (Some(count.get()), false, None)
                 }
                 Some(StressCondition::Count(StressCount::Infinite)) => (None, true, None),
@@ -411,7 +412,7 @@ where
                 elapsed: _,
             } => {
                 let total = match total {
-                    StressCount::Count(n) => Some(n.get()),
+                    StressCount::Count { count } => Some(count.get()),
                     StressCount::Infinite => None,
                 };
                 (*completed, total)
@@ -450,7 +451,7 @@ where
                 elapsed: _,
             } => {
                 let total = match total {
-                    StressCount::Count(n) => Some(n.get()),
+                    StressCount::Count { count } => Some(count.get()),
                     StressCount::Infinite => None,
                 };
                 (*completed - 1, total)
@@ -912,8 +913,8 @@ where
     fn finish_test(
         &mut self,
         key: TestInstanceId<'a>,
-        last_run_status: ExecuteStatus,
-    ) -> ExecutionStatuses {
+        last_run_status: ExecuteStatus<ChildSingleOutput>,
+    ) -> ExecutionStatuses<ChildSingleOutput> {
         self.running_tests
             .remove(&key)
             .unwrap_or_else(|| {
@@ -1208,7 +1209,7 @@ impl DispatcherStressContext {
                 // completed runs.
                 let current = *completed;
                 let total = match condition {
-                    StressCondition::Count(StressCount::Count(total)) => Some(*total),
+                    StressCondition::Count(StressCount::Count { count }) => Some(*count),
                     StressCondition::Count(StressCount::Infinite)
                     | StressCondition::Duration(_) => None,
                 };
@@ -1236,7 +1237,7 @@ impl DispatcherStressContext {
                         // TODO: We should figure out whether to terminate the
                         // test run based on this.
                     }
-                    FinalRunStats::Failed(_) => {
+                    FinalRunStats::Failed { .. } => {
                         *failed += 1;
                     }
                     FinalRunStats::Cancelled { .. } => {
@@ -1331,16 +1332,19 @@ struct ContextTestInstance<'a> {
     // Store the instance primarily for debugging.
     #[expect(dead_code)]
     instance: TestInstance<'a>,
-    past_attempts: Vec<ExecuteStatus>,
+    past_attempts: Vec<ExecuteStatus<ChildSingleOutput>>,
     req_tx: UnboundedSender<RunUnitRequest<'a>>,
 }
 
 impl ContextTestInstance<'_> {
-    fn attempt_failed_will_retry(&mut self, run_status: ExecuteStatus) {
+    fn attempt_failed_will_retry(&mut self, run_status: ExecuteStatus<ChildSingleOutput>) {
         self.past_attempts.push(run_status);
     }
 
-    fn finish(self, last_run_status: ExecuteStatus) -> ExecutionStatuses {
+    fn finish(
+        self,
+        last_run_status: ExecuteStatus<ChildSingleOutput>,
+    ) -> ExecutionStatuses<ChildSingleOutput> {
         let mut attempts = self.past_attempts;
         attempts.push(last_run_status);
         ExecutionStatuses::new(attempts)
